@@ -6,7 +6,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2023 Univention GmbH
+# Copyright 2004-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -37,16 +37,14 @@ import os
 from functools import wraps
 from pwd import getpwnam
 
-from six import string_types
-
 from univention.config_registry import ConfigRegistry
 
 
 try:
     from types import TracebackType  # noqa: F401
-    from typing import Any, Callable, List, Optional, Text, Type, TypeVar, Union  # noqa: F401
+    from typing import Any, Callable, List, Optional, Type, TypeVar, Union  # noqa: F401
 
-    _F = TypeVar("_F", bound=Callable[..., Any])
+    _F = TypeVar("_F", bound=Callable[..., Any])  # noqa: PYI018
 except ImportError:
     pass
 
@@ -54,7 +52,7 @@ configRegistry = ConfigRegistry()
 configRegistry.load()
 
 
-def setuid(uid):  # type: (Union[int, Text]) -> None
+def setuid(uid):  # type: (Union[int, str]) -> None
     """
     Set the current process’s effective user id.
     Use :py:func:`unsetuid()` to return to the listeners UID.
@@ -67,7 +65,7 @@ def setuid(uid):  # type: (Union[int, Text]) -> None
     :type uid: int or str
     :return: None
     """
-    if isinstance(uid, string_types):
+    if isinstance(uid, str):
         uid = getpwnam(uid)[2]
     assert isinstance(uid, int)
     os.seteuid(uid)
@@ -92,7 +90,7 @@ def unsetuid():  # type: () -> None
     os.seteuid(__listener_uid)
 
 
-def run(exe, argv, uid=-1, wait=True):  # type: (str, List[Union[str, Text]], int, bool) -> int
+def run(exe, argv, uid=-1, wait=True):  # type: (str, List[Union[str, str]], int, bool) -> int
     """
     Execute a the program `exe` with arguments `argv` and effective user id
     `uid`.
@@ -114,7 +112,7 @@ def run(exe, argv, uid=-1, wait=True):  # type: (str, List[Union[str, Text]], in
 
     waitp = os.P_WAIT if wait else os.P_NOWAIT
     try:
-        rc = os.spawnv(waitp, exe, argv)
+        rc = os.spawnv(waitp, exe, argv)  # noqa: S606
     except BaseException:
         rc = 100
     finally:
