@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2023 Univention GmbH
+# Copyright 2017-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -19,7 +19,8 @@
 # cryptographic keys etc. are subject to a license agreement between
 # you and Univention.
 #
-# This program is provided in the hope that it will be useful,
+# In the case you use this program under the terms of the GNU AGPL V3,
+# the program is provided in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Affero General Public License for more details.
@@ -42,7 +43,6 @@ To create a listener module (LM) with this API, create a Python file in
 See :file:`/usr/share/doc/univention-directory-listener/examples/` for examples.
 """
 
-from __future__ import absolute_import
 
 from .api_adapter import ListenerModuleAdapter
 from .exceptions import ListenerModuleConfigurationError, ListenerModuleRuntimeError
@@ -51,6 +51,9 @@ from .handler_configuration import ListenerModuleConfiguration
 
 
 __all__ = [
-    'ListenerModuleAdapter', 'ListenerModuleConfigurationError', 'ListenerModuleRuntimeError',
-    'ListenerModuleConfiguration', 'ListenerModuleHandler',
+    'ListenerModuleAdapter',
+    'ListenerModuleConfiguration',
+    'ListenerModuleConfigurationError',
+    'ListenerModuleHandler',
+    'ListenerModuleRuntimeError',
 ]
