@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2023 Univention GmbH
+# Copyright 2017-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -19,7 +19,8 @@
 # cryptographic keys etc. are subject to a license agreement between
 # you and Univention.
 #
-# This program is provided in the hope that it will be useful,
+# In the case you use this program under the terms of the GNU AGPL V3,
+# the program is provided in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Affero General Public License for more details.
@@ -29,7 +30,6 @@
 # /usr/share/common-licenses/AGPL-3; if not, see
 # <https://www.gnu.org/licenses/>.
 
-from __future__ import absolute_import
 
 import inspect
 import os
@@ -39,8 +39,6 @@ from typing import (  # noqa: F401
     TYPE_CHECKING, Any, Dict, Iterable, Iterator, List, Mapping, Optional, Sequence, Tuple, Type, Union, cast,
 )
 
-from six import reraise, with_metaclass
-
 from univention.admin.uldap import access, position
 
 import listener
@@ -73,7 +71,7 @@ class HandlerMetaClass(type):
         return kls
 
 
-class ListenerModuleHandler(with_metaclass(HandlerMetaClass)):
+class ListenerModuleHandler(metaclass=HandlerMetaClass):
     """
     Listener module base class.
 
@@ -259,7 +257,7 @@ class ListenerModuleHandler(with_metaclass(HandlerMetaClass)):
         :param traceback exc_traceback: traceback object
         """
         self.logger.exception('dn=%r command=%r\n    old=%r\n    new=%r', dn, command, old, new)
-        reraise(exc_type, exc_value, exc_traceback)
+        raise exc_value.with_traceback(exc_traceback)
 
     @property
     def lo(self):
