@@ -3,7 +3,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2017-2023 Univention GmbH
+# Copyright 2017-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -19,7 +19,8 @@
 # cryptographic keys etc. are subject to a license agreement between
 # you and Univention.
 #
-# This program is provided in the hope that it will be useful,
+# In the case you use this program under the terms of the GNU AGPL V3,
+# the program is provided in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU Affero General Public License for more details.
@@ -41,7 +42,6 @@ additionally to the common `listener.log`.
 # ucs-school-4.2/ucs-school-lib/python/models/utils.py
 #
 
-from __future__ import absolute_import
 
 import grp
 import logging
@@ -49,12 +49,10 @@ import os
 import pwd
 import stat
 import syslog
-from collections import Mapping
-from logging.handlers import TimedRotatingFileHandler
+from collections.abc import Mapping
+from logging.handlers import WatchedFileHandler
 from typing import IO, Any, Dict, Optional, Type  # noqa: F401
 
-from six import PY2, string_types, text_type
-
 import univention.debug as ud
 from univention.config_registry import ConfigRegistry
 
@@ -64,7 +62,7 @@ import listener
 __syslog_opened = False
 
 
-class UniFileHandler(TimedRotatingFileHandler):
+class UniFileHandler(WatchedFileHandler):
     """
     Used by listener modules using the :py:mod:`univention.listener` API to
     write log files below :file:`/var/log/univention/listener_log/`.
@@ -74,21 +72,31 @@ class UniFileHandler(TimedRotatingFileHandler):
 
     def _open(self):
         # type: () -> IO[str]
-        stream = TimedRotatingFileHandler._open(self)
-        file_stat = os.fstat(stream.fileno())
+        newly_created = not os.path.exists(self.baseFilename)
+
+        try:
+            stream = WatchedFileHandler._open(self)
+        except PermissionError:
+            self._set_listener_module_log_file_permissions()
+            stream = WatchedFileHandler._open(self)
+
+        if newly_created:
+            # Bug #55610: When Python creates a new file every user is able to read it
+            self._set_listener_module_log_file_permissions()
+        return stream
+
+    def _set_listener_module_log_file_permissions(self):
         listener_uid = pwd.getpwnam('listener').pw_uid
         adm_gid = grp.getgrnam('adm').gr_gid
-        if file_stat.st_uid != listener_uid or file_stat.st_gid != adm_gid:
-            old_uid = os.geteuid()
-            try:
-                if old_uid != 0:
-                    listener.setuid(0)
-                os.fchown(stream.fileno(), listener_uid, adm_gid)
-                os.fchmod(stream.fileno(), stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)
-            finally:
-                if old_uid != 0:
-                    listener.unsetuid()
-        return stream
+        old_uid = os.geteuid()
+        try:
+            if old_uid != 0:
+                listener.setuid(0)
+            os.chown(self.baseFilename, listener_uid, adm_gid)
+            os.chmod(self.baseFilename, stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP)
+        finally:
+            if old_uid != 0:
+                listener.unsetuid()
 
 
 class ModuleHandler(logging.Handler):
@@ -116,8 +124,6 @@ class ModuleHandler(logging.Handler):
     def emit(self, record):
         # type: (logging.LogRecord) -> None
         msg = self.format(record)
-        if PY2 and isinstance(msg, text_type):
-            msg = msg.encode('utf-8')
         msg = '{}: {}'.format(record.name.rsplit('.')[-1], msg)
         udebug_level = self.LOGGING_TO_UDEBUG[record.levelname]
         ud.debug(self._udebug_facility, udebug_level, msg)
@@ -266,8 +272,8 @@ def get_listener_logger(name, filename, level=None, handler_kwargs=None, formatt
     :return: a Python logging object
     :rtype: logging.Logger
     """
-    assert isinstance(filename, string_types)
-    assert isinstance(name, string_types)
+    assert isinstance(filename, str)
+    assert isinstance(name, str)
     if not name:
         name = 'noname'
     name = name.replace('.', '_')  # don't mess up logger hierarchy
@@ -310,7 +316,7 @@ def get_listener_logger(name, filename, level=None, handler_kwargs=None, formatt
             handler.setFormatter(formatter)
     else:
         # Create handler and formatter from scratch.
-        handler = UniFileHandler(filename=filename, when='W6', backupCount=60, **handler_kwargs)
+        handler = UniFileHandler(filename=filename, **handler_kwargs)
         handler.set_name(logger_name)
         handler.setLevel(level)
         formatter_cls = fmt_kwargs.pop('cls')
