@@ -2,7 +2,10 @@
  * Univention Directory Listener
  *  demo program for the notifier client API.
  *
- * Copyright 2004-2022 Univention GmbH
+ * Like what you see? Join us!
+ * https://www.univention.com/about-us/careers/vacancies/
+ *
+ * Copyright 2004-2024 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -39,6 +42,7 @@
 
 #include "network.h"
 #include "common.h"
+#include "utils.h"
 
 int INIT_ONLY = 0;
 
@@ -74,16 +78,16 @@ int main(int argc, char *argv[]) {
 		return 1;
 	}
 
-	if (notifier_client_new(NULL, argv[optind], 1) != 0) {
+	if (NOTIFIER_CLIENT_NEW_RETRY(notifier_client_new(NULL, argv[optind], 1)) != 0) {
 		fprintf(stderr, "Could not connect to notifier\n");
 		return 1;
 	}
 
 	if (strcmp(argv[optind + 1], "get_id") == 0) {
-		notifier_get_id_s(NULL, &id);
+		NOTIFIER_RETRY(notifier_get_id_s(NULL, &id));
 		printf("%ld\n", id);
 	} else if (strcmp(argv[optind + 1], "get_schema_id") == 0) {
-		notifier_get_schema_id_s(NULL, &id);
+		NOTIFIER_RETRY(notifier_get_schema_id_s(NULL, &id));
 		printf("%ld\n", id);
 	} else if (strcmp(argv[optind + 1], "get_dn") == 0) {
 		int msgid;
@@ -102,7 +106,7 @@ int main(int argc, char *argv[]) {
 		}
 
 		msgid = notifier_get_dn(NULL, getid);
-		notifier_get_dn_result(NULL, msgid, &entry);
+		NOTIFIER_RETRY(notifier_get_dn_result(NULL, msgid, &entry));
 
 		printf("%ld %s\n", entry.id, entry.dn);
 	} else {
