@@ -5,7 +5,7 @@
  * Like what you see? Join us!
  * https://www.univention.com/about-us/careers/vacancies/
  *
- * Copyright 2004-2023 Univention GmbH
+ * Copyright 2004-2024 Univention GmbH
  *
  * https://www.univention.de/
  *
@@ -45,10 +45,10 @@
 #include <limits.h>
 #include <sys/types.h>
 #define PY_SSIZE_T_CLEAN
-#include <python3.7/Python.h>
-#include <python3.7/compile.h>
-#include <python3.7/marshal.h>
-#include <python3.7/node.h>
+#include <python3.9/Python.h>
+#include <python3.9/compile.h>
+#include <python3.9/marshal.h>
+#include <python3.9/node.h>
 #include <univention/debug.h>
 
 #include "cache_lowlevel.h"
@@ -139,17 +139,32 @@ static PyObject *module_get_object(PyObject *module, char *name) {
 }
 
 
+/* Retrieve bool(name) from Python module.  */
+static bool module_get_bool(PyObject *module, char *name) {
+	PyObject *attr;
+	int result;
+	attr = module_get_object(module, name);
+	result = PyObject_IsTrue(attr);
+	Py_XDECREF(attr);
+	return result == 1;
+}
+
+
 /* Retrieve string from Python module. */
 static char *module_get_string(PyObject *module, char *name) {
 	PyObject *var;
 	char *str1, *str2 = NULL;
 
 	if ((var = PyObject_GetAttrString(module, name)) == NULL)
-		goto error0;
-	PyArg_Parse(var, "s", &str1);
+		goto error1;
+	if (!PyUnicode_Check(var))
+	    goto error0;
+	if (PyArg_Parse(var, "s", &str1) != 1)
+	    goto error0;
 	str2 = strdup(str1);
-	Py_XDECREF(var);
 error0:
+	Py_XDECREF(var);
+error1:
 	return str2;
 }
 
@@ -218,18 +233,17 @@ static int handler_import(char *filename) {
 		goto error;
 	}
 
-	handler->name = module_get_string(handler->module, "name"); /* required */
-	if (handler->name == NULL) {
-		error_msg = "module_get_string(\"name\")";
-		goto error;
+	handler->name = module_get_string(handler->module, "name"); /* optional */
+	if (handler->name == NULL || !handler->name) {
+		free(handler->name);
+		char *dot = rindex(filename, '.');
+		char *slash = rindex(filename, '/');
+		char *basename = slash ? slash + 1 : filename;
+		handler->name = strndup(basename, dot - slash - 1);
 	}
 
 	if (PyObject_HasAttrString(handler->module, "modrdn")) { /* optional */
-		handler->modrdn = module_get_string(handler->module, "modrdn");
-		if (handler->modrdn == NULL) {
-			error_msg = "module_get_string(\"modrdn\")";
-			goto error;
-		}
+		handler->modrdn = module_get_bool(handler->module, "modrdn");
 	}
 	PyErr_Clear();  // Silent error when attribute is not set
 
@@ -330,7 +344,6 @@ error:
 	}
 	free(handler->filters);
 	free(handler->description);
-	free(handler->modrdn);
 	free(handler->name);
 	free(handler);
 	univention_debug(UV_DEBUG_LISTENER, UV_DEBUG_ERROR, "import of filename=%s failed in %s", filename, error_msg ? error_msg : "???");
